# Produce an alphabet for importing into FR
# Simply set the values of char_names, mapped_names, Char_base and Alpha_name,
# then run:
#
# ruby makealpha.rb >>queue.txt
#
# ruby makealpha.rb >import.txt
#
# The values for the Cherokee (Tsalagi) and Katakana syllablries are included.
# You must be using a character set that can display your chosen alphabet.
#
# *** WARNING:  The Katakana here has ERRORS which I have not corrected,
# *** in mapped_names, owing to lack of time/priority.

# Start of Unicode set
Char_base = 0x30A0

# Leave this one here in case anyone wants to use it.
$tsalagi_names = [ "a", "e", "i", "o", "u", "v", "ga", "ka", "ge", "gi", "go", "gu", "gv",
		"ha", "he", "hi", "ho", "hu", "hv", "la", "le", "li", "lo", "lu", "lv",
		"ma", "me", "mi", "mo", "mu", "na", "hna", "nah", "ne", "ni", "no", "nu", "nv",
		"qua", "que", "qui", "quo", "quu", "quv", "sa", "s", "se", "si", "so", "su", "sv",
		"da", "ta", "de", "te", "di", "ti", "do", "du", "dv",
		"dla", "tla", "tle", "tli", "tlo", "tlu", "tlv", "tsa", "tse", "tsi", "tso", "tsu", "tsv",
		"wa", "we", "wi", "wo", "wu", "wv", "ya", "ye", "yi", "yo", "yu", "yv" ]

# List of character names
$char_names = [ nil, "a", nil, "i", nil, "u", nil, "e", nil, "o", "ka", "ga", "ki", "gi", "ku", "gu", "ke", "ge",
		"ko", "go", "sa", "za", "si / shi", "zi / ji", "su", "zu", "se", "ze", "so", "zo", "ta", "da",
		"ti / chi", "ji (old form)", nil, "tsu", "zu (old form)", "te", "de", "to", "zo / do", "na", "ni", "nu", "ne", "no",
		"ha", "ba", "pa", "hi", "bi", "pi", "hu / fu", "bu", "pu", "he", "be", "pe", "ho", "bo", "po",
		"ma", "mi", "mu", "me", "mo", nil, "ya", nil, "yu", nil, "yo", "ra", "ri", "ru", "re", "ro",
		nil, "wa", "wi", "we", "wo", "n", "vu", nil, nil, "va", "vi", "ve", "vo" ]

$mapped_names = {
		"kya" => [ 0x304D, 0x30E3 ],
		"sha" => [ 0x30B7, 0x30E3 ],
		"cha" => [ 0x30B5, 0x30E3 ],
		"nya" => [ 0x30CB, 0x30E3 ],
		"hya" => [ 0x30D2, 0x30E3 ],
		"mya" => [ 0x30DF, 0x30E3 ],
		"rya" => [ 0x30EA, 0x30E3 ],
		"gya" => [ 0x30AE, 0x30E3 ],
		"bya" => [ 0x30D3, 0x30E3 ],
		"pya" => [ 0x30D4, 0x30E3 ],
		"ja" => [ 0x30B4, 0x30E3 ],
		"ja (old form)" => [ 0x30C2, 0x30E3 ],
		"kyu" => [ 0x30AD, 0x30E5 ],
		"shu" => [ 0x30B7, 0x30E5 ],
		"chu" => [ 0x30B5, 0x30E5 ],
		"nyu" => [ 0x30CB, 0x30E5 ],
		"hyu" => [ 0x30D2, 0x30E5 ],
		"myu" => [ 0x30DF, 0x30E5 ],
		"ryu" => [ 0x30EA, 0x30E5 ],
		"gyu" => [ 0x30AE, 0x30E5 ],
		"byu" => [ 0x30D3, 0x30E5 ],
		"pyu" => [ 0x30D4, 0x30E5 ],
		"ju" => [ 0x30B8, 0x30E5 ],
		"ju (old form)" => [ 0x30C2, 0x30E5 ],
		"kyo" => [ 0x30AD, 0x30E7 ],
		"sho" => [ 0x30B7, 0x30E7 ],
		"cho" => [ 0x30B5, 0x30E7 ],
		"nyo" => [ 0x30CB, 0x30E7 ],
		"hyo" => [ 0x30D2, 0x30E7 ],
		"myo" => [ 0x30DF, 0x30E7 ],
		"ryo" => [ 0x30EA, 0x30E7 ],
		"gyo" => [ 0x30AE, 0x30E7 ],
		"byo" => [ 0x30D3, 0x30E7 ],
		"pyo" => [ 0x30D4, 0x30E7 ],
		"jo" => [ 0x30B8, 0x30E7 ],
		"jo (old form)" => [ 0x30C2, 0x30E7 ]
	}

Alpha_name = "Katakana"

# No user-serviceable parts below here.

def number_to_8(the_char)
	if the_char < 0x80
		(the_char).chr
	elsif the_char < 0x800
		(0xC0 + the_char / 0x40).chr + (0x80 + the_char % 0x40).chr
	else
		(0xE0 + the_char / 0x1000).chr + (0x80 + (the_char / 0x40) % 0x40).chr + (0x80 + the_char % 0x40).chr
	end
end

def add_up_words(number_list)
	number_list.map {|word| number_to_8(word) }.join
end

print "<category name=\"", Alpha_name, "\">\n\n"

$char_names.each_index {|position|
	if $char_names[position] != nil
		print "<q>", number_to_8(Char_base + position), "</q>\n"
		print "<a>", $char_names[position], "</a>\n"
	end
}
$mapped_names.each_pair {|name, value|
	print "<q>", add_up_words(value), "</q>\n"
	print "<a>", name, "</a>\n"
}

print "\n</category>\n"
